/// <reference types="node" />
import { Result, Runtime } from 'stopify-continuations';
import { Serializer } from '../utils/serializer';
/**
 * Wrapped value returned from checkpoint handlers.
 */
export declare class Checkpoint {
    value: any;
    constructor(value: any);
}
export declare type PromiseStatus = 'pending' | 'fulfilled' | 'rejected';
export declare type PromiseHandler<T1, T2> = {
    onFulfilled: (v: any) => T1 | PromiseLike<T1>;
    onRejected: (e: any) => T2 | PromiseLike<T2>;
};
export interface ReifiedPromise<T> {
    status: PromiseStatus;
    value?: T;
    handlers: PromiseHandler<any, any>[];
    resolvesTo?: Promise<any>;
}
/**kO
 * Frontend to continuations implementing serializable checkpoints.
 */
export declare class CheckpointRuntime extends Serializer {
    rts: Runtime;
    private eventMode;
    private eventQueue;
    onDone: (result: Result) => void;
    onEnd: (result: any) => void;
    constructor(rts: Runtime);
    /**
     * Primitive to build extensible functionality handling continuations and
     * checkpointing.
     *
     * @param fn - called with the base64-encoded continuation
     */
    checkpoint(fn?: (k: string) => any): any;
    fork(count: number, serviceUrl: string, continuation: string): Promise<any>;
    exec({ action, args, payload, serviceUrl, }: {
        action: string;
        args: any;
        payload?: any;
        serviceUrl: string;
    }): Promise<any>;
    join(args: any): Promise<any>;
    resume(buffer: Buffer, entrypoint: () => (() => any)): void;
    sleep(ms: number): void;
    /**
     * Support for suspensions in `async/await` programming model.
     *
     * Programs using `async/await` sequentially chain `Promise` resolutions,
     * i.e. there is no coordination between resolving multiple promises "in
     * parallel". Top-level calls to async functions return a Promise containing
     * either the resolved value or a stack capture exception in the case of a
     * suspended async function. Since this exception cannot escape the Promise,
     * top-level async function calls must be wrapped by the `promise` function
     * to asynchronously restore the continuation contained within the promise,
     * and continue the promise chain.
     */
    promise(p: Promise<any>): any;
    /**
     * Adds a function to internal event queue. Used to make Distribufy aware of
     * asynchronous events like `setTimeout`.
     *
     * @param body     - function pushed to internal event queue
     * @param receiver - function to handle result of `body`. Called when `body`
     *                   terminates
     */
    processEvent(body: () => void, receiver: (x: Result) => void): void;
    private processQueuedEvents;
}
