/// <reference types="node" />
import { Serializer } from '../utils/serializer';
/**
 * `Pickler` wraps the v8 serialization API with methods for serializing
 * user-defined and native function values.
 */
export declare class Pickler {
    /** Map Function objects to ids to support sharing */
    private fn_id_map;
    /** Map Promises to ids to support sharing */
    private promise_id_map;
    /** The next id to assign a shared object that gets restructured */
    private fn_id;
    private promise_id;
    /** Reified fn objects that get assigned to object for serialization */
    private fns;
    private promises;
    private restructureProperties;
    private restructureFn;
    private restructurePromise;
    private restructureMap;
    private restructure;
    serializePromise(map: Map<any, any>, p: Promise<any>): any;
    /**
     * Write the object `o` to a `Buffer`.
     *
     * Supports serialization of Function objects and class instances in
     * cooperation with the `Depickler` deserialization API.
     */
    serialize(o: any): Buffer;
}
/**
 * `Depickler` wraps the v8 deserialization API with methods for deserializing
 * user-defined and native function values.
 *
 * Functions are deserialized to their textual representation and must be
 * reallocated within the same scope as the originally defined function, i.e.
 * closed-over variables within the serialized function must be restored to the
 * scope before the function is reallocated from its string representation.
 */
export declare class Depickler {
    private runtime;
    constructor(runtime: Serializer);
    /** Map Function objects to ids to support sharing */
    private fn_map;
    /** Map Promises to ids to support sharing */
    private promise_map;
    private filterFnProperties;
    private reconstructFn;
    private reconstructProperties;
    private dispatch;
    private reconstructPromise;
    private reconstruct;
    /**
     * Deserialize the `Buffer` `buffer` into an object.
     *
     * Supports deserialization of Function objects and class instances in
     * cooperation with the `Pickler` Serialization API.
     */
    deserialize(buffer: Buffer): any;
}
