/// <reference types="node" />
import { Stack } from 'stopify-continuations';
import { ReifiedPromise } from '../runtime/checkpointable';
export declare class Serializer {
    private pickle;
    private depickle;
    /**
     * Maps identifiers to values to be persisted for initialization code re-run
     * when restoring checkpoints.
     */
    persistent_map: Map<string, any>;
    /** Maps `Promise` references to reified promise state for serialization. */
    promises: Map<Promise<any>, ReifiedPromise<any>>;
    modules: Map<string, any>;
    /**
     * Utility function to persist non-deterministic initialization code that
     * gets rerun across checkpoints.
     *
     * @param id - Identifier storing persisted value in serialized Map
     * @param e  - Thunk which evaluates to the value to be persisted
     */
    persist<T>(id: string, e: () => T): T;
    require(path: string): any;
    serialize(continuation: Stack): Buffer;
    deserialize(buffer: Buffer): Stack;
}
